==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/user_round_cog.py <==
from .. import IconBase


class IconUserRoundCog(IconBase):
    class_name = "lucide lucide-user-round-cog"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 21a8 8 0 0 1 10.434-7.62"
            }
        },
        {
            "circle": {
                "cx": "10",
                "cy": "8",
                "r": "5"
            }
        },
        {
            "circle": {
                "cx": "18",
                "cy": "18",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "m19.5 14.3-.4.9"
            }
        },
        {
            "path": {
                "d": "m16.9 20.8-.4.9"
            }
        },
        {
            "path": {
                "d": "m21.7 19.5-.9-.4"
            }
        },
        {
            "path": {
                "d": "m15.2 16.9-.9-.4"
            }
        },
        {
            "path": {
                "d": "m21.7 16.5-.9.4"
            }
        },
        {
            "path": {
                "d": "m15.2 19.1-.9.4"
            }
        },
        {
            "path": {
                "d": "m19.5 21.7-.4-.9"
            }
        },
        {
            "path": {
                "d": "m16.9 15.2-.4-.9"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/user_round_cog.py <==
from .. import IconBase


class IconUserRoundCog(IconBase):
    class_name = "lucide lucide-user-round-cog"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 21a8 8 0 0 1 10.434-7.62"
            }
        },
        {
            "circle": {
                "cx": "10",
                "cy": "8",
                "r": "5"
            }
        },
        {
            "circle": {
                "cx": "18",
                "cy": "18",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "m19.5 14.3-.4.9"
            }
        },
        {
            "path": {
                "d": "m16.9 20.8-.4.9"
            }
        },
        {
            "path": {
                "d": "m21.7 19.5-.9-.4"
            }
        },
        {
            "path": {
                "d": "m15.2 16.9-.9-.4"
            }
        },
        {
            "path": {
                "d": "m21.7 16.5-.9.4"
            }
        },
        {
            "path": {
                "d": "m15.2 19.1-.9.4"
            }
        },
        {
            "path": {
                "d": "m19.5 21.7-.4-.9"
            }
        },
        {
            "path": {
                "d": "m16.9 15.2-.4-.9"
            }
        }
    ]
}
